import * as i0 from '@angular/core';
import { EventEmitter, Component, ViewEncapsulation, Input, Output, ViewChild, NgModule } from '@angular/core';
import * as i1 from '@sq-ui/ng-sq-common';
import { NgSqCommonModule } from '@sq-ui/ng-sq-common';
import { CommonModule } from '@angular/common';

class ModalComponent {
    constructor(renderer) {
        this.renderer = renderer;
        this.show = false;
        this.showChange = new EventEmitter();
        this.customCssAnimation = {
            duration: 0,
            entranceAnimation: '',
            exitAnimation: ''
        };
        this.listenForOutsideClick = false;
    }
    ngOnChanges(changesObj) {
        if (changesObj.show && this.sqModalWindow) {
            const entranceAnimationClass = this.customCssAnimation.entranceAnimation || 'fadeInDown';
            const exitAnimationClass = this.customCssAnimation.exitAnimation || 'fadeOutUp';
            const animationDuration = this.customCssAnimation.duration || 500;
            if (changesObj.show.currentValue === true) {
                this.renderer.removeClass(this.sqModal.nativeElement, 'display-none');
                this.renderer.addClass(this.sqModalWindow.nativeElement, entranceAnimationClass);
                setTimeout(() => {
                    this.renderer.removeClass(this.sqModalWindow.nativeElement, entranceAnimationClass);
                    this.listenForOutsideClick = true;
                }, animationDuration);
            }
            else {
                this.renderer.addClass(this.sqModalWindow.nativeElement, exitAnimationClass);
                setTimeout(() => {
                    this.renderer.addClass(this.sqModal.nativeElement, 'display-none');
                    this.renderer.removeClass(this.sqModalWindow.nativeElement, exitAnimationClass);
                    this.listenForOutsideClick = false;
                }, animationDuration);
            }
        }
    }
    close() {
        this.show = false;
        this.showChange.emit(false);
    }
    open() {
        this.show = true;
        this.showChange.emit(true);
    }
    onClickOutsideComponent() {
        this.listenForOutsideClick = false;
        this.close();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.0.4", ngImport: i0, type: ModalComponent, deps: [{ token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.0.4", type: ModalComponent, selector: "sq-modal", inputs: { show: "show", customCssAnimation: "customCssAnimation" }, outputs: { showChange: "showChange" }, viewQueries: [{ propertyName: "sqModal", first: true, predicate: ["sqModal"], descendants: true }, { propertyName: "sqModalWindow", first: true, predicate: ["sqModalWindow"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "<div class=\"modal-cover display-none\" #sqModal>\r\n  <article #sqModalWindow\r\n           class=\"modal-window animated\"\r\n           sqOutsideClickListener\r\n           [listenForOutsideClick]=\"listenForOutsideClick\"\r\n           (clickOutside)=\"onClickOutsideComponent()\">\r\n    <header class=\"modal-header-wrapper display-flex space-between align-items-center\">\r\n      <div class=\"modal-title\">\r\n        <ng-content select=\"[sq-modal-title]\"></ng-content>\r\n      </div>\r\n\r\n      <span class=\"close\" (click)=\"close()\">\r\n          <i class=\"fas fa-times\" aria-hidden=\"true\"></i>\r\n      </span>\r\n    </header>\r\n\r\n    <div class=\"content\">\r\n      <ng-content select=\"[sq-modal-body]\"></ng-content>\r\n    </div>\r\n\r\n    <footer class=\"modal-footer\">\r\n      <ng-content select=\"[sq-modal-footer]\"></ng-content>\r\n    </footer>\r\n  </article>\r\n</div>\r\n", styles: [".animated{animation-duration:.5s;animation-fill-mode:both}@keyframes fadeInDown{0%{opacity:0;transform:translate3d(0,-100%,0)}to{opacity:1;transform:translateZ(0)}}.fadeInDown{animation-name:fadeInDown}@keyframes fadeOutUp{0%{opacity:1}to{opacity:0;transform:translate3d(0,-100%,0)}}.fadeOutUp{animation-name:fadeOutUp}.sq .modal-cover{position:fixed;display:flex;justify-content:center;align-items:center;top:0;left:0;bottom:0;width:100%;background-color:#00000063;z-index:1000}.modal-cover.display-none{display:none!important}.sq .modal-window{position:relative;min-height:500px;background-color:#fff;display:flex;flex-direction:column;padding:15px;box-shadow:7px 8px #127d684d}.sq .modal-window .modal-header-wrapper{background-color:#127d6836;border-bottom:1px solid rgba(46,159,134,.69)}.sq .modal-window .modal-title{font-size:22px;padding-top:15px;padding-left:15px;padding-bottom:15px}.sq .modal-window .content{padding:15px;height:364px;overflow-y:auto;overflow-x:hidden}.sq .modal-window .modal-footer{align-self:flex-end;width:100%;padding-top:10px;padding-left:15px;padding-bottom:10px;border-top:1px solid rgba(46,159,134,.69);background-color:#127d6836}.sq .modal-window button{margin-right:10px}.sq .modal-window .close{font-size:22px;cursor:pointer;padding:10px;margin-right:15px}@media (min-width: 1301px){.sq .modal-window{width:50vw}}@media (max-width: 1300px){.sq .modal-window{max-width:800px}}@media (max-width: 900px){.sq .modal-window{width:90vw}}\n"], dependencies: [{ kind: "directive", type: i1.OutsideClickListenerDirective, selector: "[sqOutsideClickListener]", inputs: ["listenForOutsideClick"], outputs: ["clickOutside"] }], encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.0.4", ngImport: i0, type: ModalComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sq-modal', encapsulation: ViewEncapsulation.None, template: "<div class=\"modal-cover display-none\" #sqModal>\r\n  <article #sqModalWindow\r\n           class=\"modal-window animated\"\r\n           sqOutsideClickListener\r\n           [listenForOutsideClick]=\"listenForOutsideClick\"\r\n           (clickOutside)=\"onClickOutsideComponent()\">\r\n    <header class=\"modal-header-wrapper display-flex space-between align-items-center\">\r\n      <div class=\"modal-title\">\r\n        <ng-content select=\"[sq-modal-title]\"></ng-content>\r\n      </div>\r\n\r\n      <span class=\"close\" (click)=\"close()\">\r\n          <i class=\"fas fa-times\" aria-hidden=\"true\"></i>\r\n      </span>\r\n    </header>\r\n\r\n    <div class=\"content\">\r\n      <ng-content select=\"[sq-modal-body]\"></ng-content>\r\n    </div>\r\n\r\n    <footer class=\"modal-footer\">\r\n      <ng-content select=\"[sq-modal-footer]\"></ng-content>\r\n    </footer>\r\n  </article>\r\n</div>\r\n", styles: [".animated{animation-duration:.5s;animation-fill-mode:both}@keyframes fadeInDown{0%{opacity:0;transform:translate3d(0,-100%,0)}to{opacity:1;transform:translateZ(0)}}.fadeInDown{animation-name:fadeInDown}@keyframes fadeOutUp{0%{opacity:1}to{opacity:0;transform:translate3d(0,-100%,0)}}.fadeOutUp{animation-name:fadeOutUp}.sq .modal-cover{position:fixed;display:flex;justify-content:center;align-items:center;top:0;left:0;bottom:0;width:100%;background-color:#00000063;z-index:1000}.modal-cover.display-none{display:none!important}.sq .modal-window{position:relative;min-height:500px;background-color:#fff;display:flex;flex-direction:column;padding:15px;box-shadow:7px 8px #127d684d}.sq .modal-window .modal-header-wrapper{background-color:#127d6836;border-bottom:1px solid rgba(46,159,134,.69)}.sq .modal-window .modal-title{font-size:22px;padding-top:15px;padding-left:15px;padding-bottom:15px}.sq .modal-window .content{padding:15px;height:364px;overflow-y:auto;overflow-x:hidden}.sq .modal-window .modal-footer{align-self:flex-end;width:100%;padding-top:10px;padding-left:15px;padding-bottom:10px;border-top:1px solid rgba(46,159,134,.69);background-color:#127d6836}.sq .modal-window button{margin-right:10px}.sq .modal-window .close{font-size:22px;cursor:pointer;padding:10px;margin-right:15px}@media (min-width: 1301px){.sq .modal-window{width:50vw}}@media (max-width: 1300px){.sq .modal-window{max-width:800px}}@media (max-width: 900px){.sq .modal-window{width:90vw}}\n"] }]
        }], ctorParameters: function () { return [{ type: i0.Renderer2 }]; }, propDecorators: { show: [{
                type: Input
            }], showChange: [{
                type: Output
            }], customCssAnimation: [{
                type: Input
            }], sqModal: [{
                type: ViewChild,
                args: ['sqModal']
            }], sqModalWindow: [{
                type: ViewChild,
                args: ['sqModalWindow']
            }] } });

class NgModalModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.0.4", ngImport: i0, type: NgModalModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.0.4", ngImport: i0, type: NgModalModule, declarations: [ModalComponent], imports: [CommonModule,
            NgSqCommonModule], exports: [ModalComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.0.4", ngImport: i0, type: NgModalModule, imports: [CommonModule,
            NgSqCommonModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.0.4", ngImport: i0, type: NgModalModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        NgSqCommonModule
                    ],
                    declarations: [ModalComponent],
                    exports: [ModalComponent]
                }]
        }] });

/*
 * Public API Surface of ng-modal
 */

/**
 * Generated bundle index. Do not edit.
 */

export { ModalComponent, NgModalModule };
//# sourceMappingURL=sq-ui-ng-modal.mjs.map
